<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Kilépés az alkalmazásból</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Display help </source>
        <translation>Súgó megjelenítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>About this application</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>About...</source>
        <translation>Névjegy...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>View Log</source>
        <translation>Napló megtekintése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <location filename="../mainwindow.cpp" line="507"/>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>Select ISO</source>
        <translation>Válasszon ISO képfájlt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;USB eszköz kiválasztása&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;ISO fájl kiválasztása&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Speciális lehetőségek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Akkor is hozzon létre ext4 fájlrendszert, ha már létezik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Mentse az eredeti /boot könyvtárat, egy Live-USB frissítésekor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>GPT particionálást használjon, msdos helyett</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>GPT particionálás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Frissítés (csak frissítsen egy meglévő Live-USB-t)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Ne cserélje le a syslinux fájlokat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Syslinux fájlok megtartása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Hagyja figyelmen kívül az USB/eltávolítható ellenőrzést</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Átmenetileg kapcsolja ki az automatikus leválasztást</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Kapcsolja be a pmbr_boot lemez jelzőt (UEFI-vel nem fog elindulni)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Ne használja  fuseiso-t az ISO fájlok csatolásához</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Az ESP (UEFI) partíció mérete:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Verbosity (less to more):</source>
        <translation>Üzenetek részletessége (kevesebbről többre):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="506"/>
        <source>Data partition format type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Make separate data partition (percent)</source>
        <translation>Készítsen külön adat partíciót (százalék)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Refresh drive list</source>
        <translation>Lista frissítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Show advanced options</source>
        <translation>Speciális lehetőségek megjelenítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Teljes felszereltségű mód - írható LiveUSB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Csak olvasható, nem használható adatmegőrzéssel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>Képfájl mód - csak olvasható LiveUSB (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="589"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Az antiX/MX disztribúcióktól eltérő esetben használja a képfájl módot (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="637"/>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="675"/>
        <source>Percent of USB-device to use:</source>
        <translation>Az USB eszköz százalékának használata:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="682"/>
        <source>Label ext partition:</source>
        <translation>Az ext partíció címkéje:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="730"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Ne futtassa azokat a parancsokat, amelyek módosítják az USB eszközt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="733"/>
        <source>Dry run (no change to system)</source>
        <translation>Csak próba (nem végez változtatást)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="740"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Klónozás egy csatolt Live-USB eszközről vagy ISO fájlból.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <source>Clone a mounted live system</source>
        <translation>Csatolt live rendszer klónozása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Titkosított partícióról való indítás beállítása. Az első indításkor fogja bekérni a jelmondatot.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Encrypt</source>
        <translation>Titkosítás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Clone running live system</source>
        <translation>A jelenleg futó Live rendszer klónozása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="77"/>
        <source>Confirmation</source>
        <translation>Jóváhagyás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="78"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation>A cél eszköz %1 nagyobb, mint %2 GB. Kívánja folytatni?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Failure</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="113"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>A forrás és a cél ugyanazon az eszközön van. Válassza ki újra.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation>%1 írása &apos;dd&apos; parancs használatával ide: /dev/%2,

Várja meg a folyamat befejeződését</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="151"/>
        <source>MX Live Usb Maker</source>
        <translation>MX Live-USB készítő</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Success</source>
        <translation>Sikeres</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>LiveUSB creation successful!</source>
        <translation>LiveUSB készítése sikeres!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Hiba történt a LiveUSB létrehozása közben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Please select a USB device to write to</source>
        <translation>Válasszon egy USB eszközt amelyre írni szeretne</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="391"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Ez minden adatot töröl a következőről

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Do you wish to continue?</source>
        <translation>Szeretné folytatni?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>About %1</source>
        <translation>%1 névjegye</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Version: </source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>LiveUSB létrehozására szolgáló program, egy ISO fájlból, másik LiveUSB-ről, Live CD/DVD-ről, vagy a futó Live rendszerről.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>%1 License</source>
        <translation>%1 licenc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>%1 Help</source>
        <translation>%1 Súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Válassza ki az ISO fájlt amelyet az USB eszközre kiír</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>ISO fájlok (*.iso);Minden fájl (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Select Source Directory</source>
        <translation>Válassza ki a forrás könyvtárat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Could not find linuxfs file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Hide advanced options</source>
        <translation>Speciális lehetőségek elrejtése</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>Select Source</source>
        <translation>Forrás kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Select ISO file</source>
        <translation>ISO fájl kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>clone</source>
        <translation>klónozás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="589"/>
        <source>Could not find a log file at: </source>
        <translation>Nem található a napló fájl:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>License</source>
        <translation>Licenc</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <location filename="../about.cpp" line="85"/>
        <source>Changelog</source>
        <translation>Változások listája</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="99"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>LiveUSB létrehozására szolgáló program, egy ISO fájlból, másik LiveUSB-ről, Live CD/DVD-ről, vagy a futó Live rendszerről.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>filename</source>
        <translation>fájlnév</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation>A megnyitni kívánt .iso fájl neve</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>[filename]</source>
        <translation>[fájlnév]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Úgy tűnik, hogy root felhasználóként van bejelentkezve. Jelentkezzen ki és jelentkezzen be egyszerű felhasználóként a program használatához.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as root.</source>
        <translation>Root felhasználóként kell futtatnia ezt a programot.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>version:</source>
        <translation>verzió:</translation>
    </message>
</context>
</TS>
